Package: biocmake
Version: 1.0.1
Date: 2025-05-13
Title: CMake for Bioconductor
Description: 
    Manages the installation of CMake for building Bioconductor packages.
    This avoids the need for end-users to manually install CMake on their system.
    No action is performed if a suitable version of CMake is already available.
Authors@R: person("Aaron", "Lun", role=c("cre", "aut"), email="infinite.monkeys.with.keyboards@gmail.com")
License: MIT + file LICENSE
Encoding: UTF-8
VignetteBuilder: knitr
Imports: utils, tools, dir.expiry
Suggests: knitr, rmarkdown, BiocStyle, testthat
biocViews: Infrastructure
URL: https://github.com/LTLA/biocmake
BugReports: https://github.com/LTLA/biocmake/issues
RoxygenNote: 7.3.2
git_url: https://git.bioconductor.org/packages/biocmake
git_branch: RELEASE_3_21
git_last_commit: 9cffd4f
git_last_commit_date: 2025-05-13
Repository: Bioconductor 3.21
Date/Publication: 2025-05-18
NeedsCompilation: no
Packaged: 2025-05-18 20:19:36 UTC; biocbuild
Author: Aaron Lun [cre, aut]
Maintainer: Aaron Lun <infinite.monkeys.with.keyboards@gmail.com>
